pub fn save(canvas: &Canvas, path: &str, renderer: impl Renderer) -> Result<()>Expand description
Saves a canvas to disk. Note: Will overwrite any existing file at the path you provide.
canvas- Reference to the canvas you want to savepath- Full or relative path to where you want to save the filerenderer- An object that implements theRenderertrait